@@ -215,14 +215,14 @@ class Storage:
 
             asyncio.create_task(sub.run_query())
             self.clients[client_id][sub_id] = sub
-            LOG.info("%s/%s +", client_id, sub_id)
+            LOG.debug("%s/%s +", client_id, sub_id)
 
     async def unsubscribe(self, client_id, sub_id=None):
         if sub_id:
             try:
                 self.clients[client_id][sub_id].cancel()
                 del self.clients[client_id][sub_id]
-                LOG.info("%s/%s -", client_id, sub_id)
+                LOG.debug("%s/%s -", client_id, sub_id)
             except KeyError:
                 pass
         elif client_id in self.clients:
@@ -308,7 +308,7 @@ class Storage:
 
 
 class Subscription:
-    def __init__(self, db, sub_id, filters:list, queue=None, client_id=None, default_limit=5000):
+    def __init__(self, db, sub_id, filters:list, queue=None, client_id=None, default_limit=6000):
         self.db  = db
         self.sub_id = sub_id
         self.client_id = client_id
@@ -334,20 +334,21 @@ class Subscription:
 
         query = self.query
         LOG.debug(query)
-
+        sub_id = self.sub_id
+        queue = self.queue
         try:
             count = 0
             with catchtime() as t:
                 async with self.db.execute(query) as cursor:
                     async for row in cursor:
                         eid, event = row
-                        await self.queue.put((self.sub_id, event))
+                        await queue.put((sub_id, event))
                         count += 1
-                await self.queue.put((self.sub_id, None))
+                await queue.put((sub_id, None))
 
             duration = t()
             LOG.info('%s/%s query – events:%s duration:%dms', self.client_id, self.sub_id, count, duration)
-            if count > 2000:
+            if duration > 500:
                 LOG.warning("%s/%s Long query: '%s' took %dms", self.client_id, self.sub_id, rapidjson.dumps(self.filters), duration)
         except Exception:
             LOG.exception("subscription")
@@ -360,7 +361,8 @@ class Subscription:
 
         with catchtime() as t:
             matched = self.check_event(event, self.filters)
-        LOG.debug('%s/%s notify match %s %s duration:%.2fms', self.client_id, self.sub_id, event.id, matched, t())
+        duration = t()
+        LOG.debug('%s/%s notify match %s %s duration:%.2fms', self.client_id, self.sub_id, event.id, matched, duration)
         if matched:
             await self.queue.put((self.sub_id, event))
 
@@ -502,19 +504,17 @@ class BaseGarbageCollector:
             collected = 0
             cursor = None
             try:
-                cursor = await self.db.cursor()
-                collected = await self.collect(cursor)
+                async with self.db.cursor() as cursor:
+                    collected = await self.collect(cursor)
+                if collected:
+                    self.log.info("Collected garbage (%d events)", collected)
+                await self.db.commit()
             except sqlite3.OperationalError as e:
                 self.log.exception("collect")
                 break
             except Exception:
                 self.log.exception("collect")
-            finally:
-                if cursor:
-                    await cursor.close()
-            if collected:
-                self.log.info("Collected garbage (%d events)", collected)
-                await db.commit()
+                continue
         self.log.info("Stopped")
 
     def stop(self):
